# Changelog

## Release v1.0.0

* Updated Quote object with cleaner dot-notation
* Updated QuoteStreamer constructor for callback methods
* Removed singleton behavior from QuoteStreamer (breaking change)
* Migrated websocket-client to v1.1.0
* Fixed small code issues

## Release v0.1.5

* Integrated Deepsource
* Fixed parser issues

## Release v0.1.4

* Reader now implements protocol buffer
* Added support for new data fields
* Increased efficiency with available_fields

## Release v0.1.3

* Added non blocking thread for running web socket as background process. Resolves issue #1
* Added additional docstring documentation.

## Release v0.1.2

* Added bumpversion. 
## Release v0.1.1

Initial release.
